COMMAND_KEYWORDS = ['help', 'limit', 'tables', 'ddl', 'quit']

SQL_KEYWORDS = ['ABS',
                'ABSOLUTE',
                'ACOS',
                'ACTION',
                'ADD',
                'AFTER',
                'ALL',
                'ALLOCATE',
                'ALTER',
                'AND',
                'ANY',
                'ARE',
                'ARRAY',
                'ARRAY_AGG',
                'ARRAY_MAX_CARDINALITY',
                'AS',
                'ASC',
                'ASENSITIVE',
                'ASIN',
                'ASSERTION',
                'ASYMMETRIC',
                'AT',
                'ATAN',
                'ATOMIC',
                'AUTHORIZATION',
                'AVG',
                'BEFORE',
                'BEGIN',
                'BEGIN_FRAME',
                'BEGIN_PARTITION',
                'BETWEEN',
                'BIGINT',
                'BINARY',
                'BIT',
                'BIT_LENGTH',
                'BLOB',
                'BOOLEAN',
                'BOTH',
                'BREADTH',
                'BY',
                'CALL',
                'CALLED',
                'CARDINALITY',
                'CASCADE',
                'CASCADED',
                'CASE',
                'CAST',
                'CATALOG',
                'CEIL',
                'CEILING',
                'CHAR',
                'CHAR_LENGTH',
                'CHARACTER',
                'CHARACTER_LENGTH',
                'CHECK',
                'CLASSIFIER',
                'CLOB',
                'CLOSE',
                'COALESCE',
                'COLLATE',
                'COLLATION',
                'COLLECT',
                'COLUMN',
                'COMMIT',
                'CONDITION',
                'CONNECT',
                'CONNECTION',
                'CONSTRAINT',
                'CONSTRAINTS',
                'CONSTRUCTOR',
                'CONTAINS',
                'CONTINUE',
                'CONVERT',
                'COPY',
                'CORR',
                'CORRESPONDING',
                'COS',
                'COSH',
                'COUNT',
                'COVAR_POP',
                'COVAR_SAMP',
                'CREATE',
                'CROSS',
                'CUBE',
                'CUME_DIST',
                'CURRENT',
                'CURRENT_CATALOG',
                'CURRENT_DATE',
                'CURRENT_DEFAULT_TRANSFORM_GROUP',
                'CURRENT_PATH',
                'CURRENT_ROLE',
                'CURRENT_ROW',
                'CURRENT_SCHEMA',
                'CURRENT_TIME',
                'CURRENT_TIMESTAMP',
                'CURRENT_TRANSFORM_GROUP_FOR_TYPE',
                'CURRENT_USER',
                'CURSOR',
                'CYCLE',
                'DATA',
                'DATE',
                'DAY',
                'DEALLOCATE',
                'DEC',
                'DECFLOAT',
                'DECIMAL',
                'DECLARE',
                'DEFAULT',
                'DEFERRABLE',
                'DEFERRED',
                'DEFINE',
                'DELETE',
                'DENSE_RANK',
                'DEPTH',
                'DEREF',
                'DESC',
                'DESCRIBE',
                'DESCRIPTOR',
                'DETERMINISTIC',
                'DIAGNOSTICS',
                'DISCONNECT',
                'DISTINCT',
                'DO',
                'DOMAIN',
                'DOUBLE',
                'DROP',
                'DYNAMIC',
                'EACH',
                'ELEMENT',
                'ELSE',
                'ELSEIF',
                'EMPTY',
                'END',
                'END_FRAME',
                'END_PARTITION',
                'END-EXEC',
                'EQUALS',
                'ESCAPE',
                'EVERY',
                'EXCEPT',
                'EXCEPTION',
                'EXEC',
                'EXECUTE',
                'EXISTS',
                'EXIT',
                'EXP',
                'EXTERNAL',
                'EXTRACT',
                'FALSE',
                'FETCH',
                'FILTER',
                'FIRST',
                'FIRST_VALUE',
                'FLOAT',
                'FOR',
                'FOREIGN',
                'FOUND',
                'FRAME_ROW',
                'FREE',
                'FROM',
                'FULL',
                'FUNCTION',
                'FUSION',
                'GENERAL',
                'GET',
                'GLOBAL',
                'GO',
                'GOTO',
                'GRANT',
                'GROUP',
                'GROUPING',
                'GROUPS',
                'HANDLER',
                'HAVING',
                'HOLD',
                'HOUR',
                'IDENTITY',
                'IF',
                'IMMEDIATE',
                'IN',
                'INDICATOR',
                'INITIAL',
                'INITIALLY',
                'INNER',
                'INOUT',
                'INPUT',
                'INSENSITIVE',
                'INSERT',
                'INT',
                'INTEGER',
                'INTERSECT',
                'INTERSECTION',
                'INTERVAL',
                'INTO',
                'IS',
                'ISOLATION',
                'ITERATE',
                'JOIN',
                'JSON_ARRAY',
                'JSON_ARRAYAGG',
                'JSON_EXISTS',
                'JSON_OBJECT',
                'JSON_OBJECTAGG',
                'JSON_QUERY',
                'JSON_TABLE',
                'JSON_TABLE_PRIMITIVE',
                'JSON_VALUE',
                'KEY',
                'LAG',
                'LANGUAGE',
                'LARGE',
                'LAST',
                'LAST_VALUE',
                'LATERAL',
                'LEAD',
                'LEADING',
                'LEAVE',
                'LEFT',
                'LEVEL',
                'LIKE',
                'LIKE_REGEX',
                'LIMIT',
                'LISTAGG',
                'LN',
                'LOCAL',
                'LOCALTIME',
                'LOCALTIMESTAMP',
                'LOCATOR',
                'LOG',
                'LOG10',
                'LOOP',
                'LOWER',
                'MAP',
                'MATCH',
                'MATCH_NUMBER',
                'MATCH_RECOGNIZE',
                'MATCHES',
                'MAX',
                'MEMBER',
                'MERGE',
                'METHOD',
                'MIN',
                'MINUTE',
                'MOD',
                'MODIFIES',
                'MODULE',
                'MONTH',
                'MULTISET',
                'NAMES',
                'NATIONAL',
                'NATURAL',
                'NCHAR',
                'NCLOB',
                'NEW',
                'NEXT',
                'NO',
                'NONE',
                'NORMALIZE',
                'NOT',
                'NTH_VALUE',
                'NTILE',
                'NULL',
                'NULLIF',
                'NUMERIC',
                'OBJECT',
                'OCCURRENCES_REGEX',
                'OCTET_LENGTH',
                'OF',
                'OFFSET',
                'OLD',
                'OMIT',
                'ON',
                'ONE',
                'ONLY',
                'OPEN',
                'OPTION',
                'OR',
                'ORDER',
                'ORDINALITY',
                'OUT',
                'OUTER',
                'OUTPUT',
                'OVER',
                'OVERLAPS',
                'OVERLAY',
                'PAD',
                'PARAMETER',
                'PARTIAL',
                'PARTITION',
                'PATH',
                'PATTERN',
                'PER',
                'PERCENT',
                'PERCENT_RANK',
                'PERCENTILE_CONT',
                'PERCENTILE_DISC',
                'PERIOD',
                'PORTION',
                'POSITION',
                'POSITION_REGEX',
                'POWER',
                'PRECEDES',
                'PRECISION',
                'PREPARE',
                'PRESERVE',
                'PRIMARY',
                'PRIOR',
                'PRIVILEGES',
                'PROCEDURE',
                'PTF',
                'PUBLIC',
                'RANGE',
                'RANK',
                'READ',
                'READS',
                'REAL',
                'RECURSIVE',
                'REF',
                'REFERENCES',
                'REFERENCING',
                'REGR_AVGX',
                'REGR_AVGY',
                'REGR_COUNT',
                'REGR_INTERCEPT',
                'REGR_R2',
                'REGR_SLOPE',
                'REGR_SXX',
                'REGR_SXY',
                'REGR_SYY',
                'RELATIVE',
                'RELEASE',
                'REPEAT',
                'RESIGNAL',
                'RESTRICT',
                'RESULT',
                'RETURN',
                'RETURNS',
                'REVOKE',
                'RIGHT',
                'ROLE',
                'ROLLBACK',
                'ROLLUP',
                'ROUTINE',
                'ROW',
                'ROW_NUMBER',
                'ROWS',
                'RUNNING',
                'SAVEPOINT',
                'SCHEMA',
                'SCOPE',
                'SCROLL',
                'SEARCH',
                'SECOND',
                'SECTION',
                'SEEK',
                'SELECT',
                'SENSITIVE',
                'SESSION',
                'SESSION_USER',
                'SET',
                'SETS',
                'SHOW',
                'SIGNAL',
                'SIMILAR',
                'SIN',
                'SINH',
                'SIZE',
                'SKIP',
                'SMALLINT',
                'SOME',
                'SPACE',
                'SPECIFIC',
                'SPECIFICTYPE',
                'SQL',
                'SQLCODE',
                'SQLERROR',
                'SQLEXCEPTION',
                'SQLSTATE',
                'SQLWARNING',
                'SQRT',
                'START',
                'STATE',
                'STATIC',
                'STDDEV_POP',
                'STDDEV_SAMP',
                'SUBMULTISET',
                'SUBSET',
                'SUBSTRING',
                'SUBSTRING_REGEX',
                'SUCCEEDS',
                'SUM',
                'SYMMETRIC',
                'SYSTEM',
                'SYSTEM_TIME',
                'SYSTEM_USER',
                'TABLE',
                'TABLESAMPLE',
                'TAN',
                'TANH',
                'TEMPORARY',
                'THEN',
                'TIME',
                'TIMESTAMP',
                'TIMEZONE_HOUR',
                'TIMEZONE_MINUTE',
                'TO',
                'TRAILING',
                'TRANSACTION',
                'TRANSLATE',
                'TRANSLATE_REGEX',
                'TRANSLATION',
                'TREAT',
                'TRIGGER',
                'TRIM',
                'TRIM_ARRAY',
                'TRUE',
                'TRUNCATE',
                'UESCAPE',
                'UNDER',
                'UNDO',
                'UNION',
                'UNIQUE',
                'UNKNOWN',
                'UNNEST',
                'UNTIL',
                'UPDATE',
                'UPPER',
                'USAGE',
                'USER',
                'USING',
                'VALUE',
                'VALUES',
                'VALUE_OF',
                'VAR_POP',
                'VAR_SAMP',
                'VARBINARY',
                'VARCHAR',
                'VARYING',
                'VERSIONING',
                'VIEW',
                'WHEN',
                'WHENEVER',
                'WHERE',
                'WHILE',
                'WIDTH_BUCKET',
                'WINDOW',
                'WITH',
                'WITHIN',
                'WITHOUT',
                'WORK',
                'WRITE',
                'YEAR',
                'ZONE',
                ]
